
import os
import sys
import subprocess

# プリンター名
printer_name = "Your_Printer_Name"
# SumatraPDFのパス
sumatra_path = r"Your_SumatraPDF_Folder_Path\SumatraPDF.exe" # SumatraPDF.exe のフルパスを指定

def print_all_pdfs(folder_path):
    # フォルダが存在するか確認
    if not os.path.isdir(folder_path):
        print(f"Error: {folder_path} does not exist.")
        return

    # フォルダ内のすべてのPDFファイルを取得
    # ファイル名を小文字にして比較　拡張子がpdfのファイルを取得
    pdf_files = [f for f in os.listdir(folder_path) if f.lower().endswith(".pdf")]
    if not pdf_files:
        print(f"No PDF files found in {folder_path}.")
        return

    # 各PDFファイルを印刷
    for pdf_file in pdf_files:
        pdf_path = os.path.join(folder_path, pdf_file)

        try:
            # SumatraPDFの印刷コマンドを実行
            subprocess.run([
                sumatra_path,
                "-print-to", printer_name,
                pdf_path
            ], check=True)
            print(f"Printed {pdf_path} successfully.")
        except subprocess.CalledProcessError as e:
            print(f"Failed to print {pdf_path}. Error: {e}")

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Usage: python print_pdfs.py <folder_path>")
    else:
        folder_path = sys.argv[1]
        print_all_pdfs(folder_path)
